# Reference App for NiziPOS B30

There isn't much to it. Just use 

```title=build.gradle.kts, module:app
  implementation("com.github.mik3y:usb-serial-for-android:3.9.0")
```

which comes from jitpack

```title="settings.gradle.kts
repositories {
        google()
        mavenCentral()
        maven("https://jitpack.io")
    }
```

And something like this:

```kotlin
private fun initSerial() {
    val manager = getSystemService(Context.USB_SERVICE) as UsbManager
    val drivers = UsbSerialProber.getDefaultProber().findAllDrivers(manager)
    if (drivers.isEmpty()) return

    val driver = drivers[0]
    val connection = manager.openDevice(driver.device) ?: return
    val port = driver.ports[0]

    port.open(connection)
    port.setParameters(115200, 8, UsbSerialPort.STOPBITS_1, UsbSerialPort.PARITY_NONE)

    serialPort = port 
}

private fun sendCommand(command: String) {
    val port = serialPort ?: return
    val commando = command + "\n";
    Thread {
        port.write(commando.toByteArray(), 1000)
    }.start()
}
```

should suffice. 

Note the "\n" at the end of command.

To make sure your app opens automatically if the device is connected, add intent-filter to the
activity:

```xml
<!-- AndroidManifest.xml-->

<intent-filter>
    <action android:name="android.hardware.usb.action.USB_DEVICE_ATTACHED" />
</intent-filter>
<meta-data
android:name="android.hardware.usb.action.USB_DEVICE_ATTACHED"
android:resource="@xml/device_filter" />

```

and 

```xml
<?xml version="1.0" encoding="utf-8"?>

<!--device_filter.xml-->
<resources>
    <usb-device
        vendor-id="6790"
        product-id="29987" />
    <usb-device
        vendor-id="1027"
        product-id="24577" />
    <usb-device
        vendor-id="6790"
        product-id="7523" />
</resources>
```

You can use `dmesg -w` or `lsusb` or things like that to get the vendor-id and product-id of the device.

This makes your app open when user connects your device automatically.